@@ -246,6 +246,7 @@ module Fog
             vol = service.volumes.create(:name => cloud_init_volume_name, :capacity => "#{File.size(iso)}b", :allocation => "0G")
             vol.upload_image(iso)
             @iso_file = cloud_init_volume_name
+            @iso_dir = File.dirname(vol.path) if vol.path
           end
         end
 
@@ -263,88 +264,20 @@ module Fog
         def addresses(service_arg=service, options={})
           mac=self.mac
 
-          # Aug 24 17:34:41 juno arpwatch: new station 10.247.4.137 52:54:00:88:5a:0a eth0.4
-          # Aug 24 17:37:19 juno arpwatch: changed ethernet address 10.247.4.137 52:54:00:27:33:00 (52:54:00:88:5a:0a) eth0.4
-          # Check if another ip_command string was provided
-          ip_command_global=service_arg.ip_command.nil? ? 'grep $mac /var/log/arpwatch.log|sed -e "s/new station//"|sed -e "s/changed ethernet address//g" |sed -e "s/reused old ethernet //" |tail -1 |cut -d ":" -f 4-| cut -d " " -f 3' : service_arg.ip_command
-          ip_command_local=options[:ip_command].nil? ? ip_command_global : options[:ip_command]
-
-          ip_command="mac=#{mac}; server_name=#{name}; "+ip_command_local
-
-          ip_address=nil
-
-          if service_arg.uri.ssh_enabled?
-
-            # Retrieve the parts we need from the service to setup our ssh options
-            user=service_arg.uri.user #could be nil
-            host=service_arg.uri.host
-            keyfile=service_arg.uri.keyfile
-            port=service_arg.uri.port
-
-            # Setup the options
-            ssh_options={}
-            ssh_options[:keys]=[ keyfile ] unless keyfile.nil?
-            ssh_options[:port]=port unless keyfile.nil?
-            ssh_options[:paranoid]=true if service_arg.uri.no_verify?
-
-            begin
-              result=Fog::SSH.new(host, user, ssh_options).run(ip_command)
-            rescue Errno::ECONNREFUSED
-              raise Fog::Errors::Error.new("Connection was refused to host #{host} to retrieve the ip_address for #{mac}")
-            rescue Net::SSH::AuthenticationFailed
-              raise Fog::Errors::Error.new("Error authenticating over ssh to host #{host} and user #{user}")
-            end
-
-            # Check for a clean exit code
-            if result.first.status == 0
-              ip_address=result.first.stdout.strip
-            else
-              # We got a failure executing the command
-              raise Fog::Errors::Error.new("The command #{ip_command} failed to execute with a clean exit code")
-            end
-
-          else
-            # It's not ssh enabled, so we assume it is
-            if service_arg.uri.transport=="tls"
-              raise Fog::Errors::Error.new("TlS remote transport is not currently supported, only ssh")
-            end
-
-            # Execute the ip_command locally
-            # Initialize empty ip_address string
-            ip_address=""
-
-            IO.popen("#{ip_command}") do |p|
-              p.each_line do |l|
-                ip_address+=l
+          ip_address = nil
+          nic = self.nics.find {|nic| nic.mac==mac}
+          if !nic.nil?
+            service.networks.all.each do |net|
+              if net.name == nic.network
+                leases = net.dhcp_leases(mac, 0)
+                # Assume the lease expiring last is the current IP address
+                ip_address = leases.sort_by { |lse| lse["expirytime"] }.last["ipaddr"] if !leases.empty?
+                break
               end
-              status=Process.waitpid2(p.pid)[1].exitstatus
-              if status!=0
-                raise Fog::Errors::Error.new("The command #{ip_command} failed to execute with a clean exit code")
-              end
-            end
-
-            #Strip any new lines from the string
-            ip_address=ip_address.chomp
-          end
-
-          # The Ip-address command has been run either local or remote now
-
-          if ip_address==""
-            #The grep didn't find an ip address result"
-            ip_address=nil
-          else
-            # To be sure that the command didn't return another random string
-            # We check if the result is an actual ip-address
-            # otherwise we return nil
-            unless ip_address=~/^(\d{1,3}\.){3}\d{1,3}$/
-              raise Fog::Errors::Error.new(
-                        "The result of #{ip_command} does not have valid ip-address format\n"+
-                            "Result was: #{ip_address}\n"
-                    )
             end
           end
 
-          return { :public => [ip_address], :private => [ip_address]}
+          return { :public => [ip_address], :private => [ip_address] }
         end
 
         def ip_address(key)
@@ -413,19 +346,16 @@ module Fog
             :network_interface_type => "network",
             :network_nat_network    => "default",
             :network_bridge_name    => "br0",
-            :boot_order             => default_boot_order,
+            :boot_order             => %w[hd cdrom network],
             :display                => default_display
           }
         end
 
-        def default_boot_order
-          %w[hd cdrom network]
-        end
-
         def verify_boot_order order = []
+          valid_boot_media = %w[cdrom fd hd network]
           if order
             order.each do |b|
-              raise "invalid boot order, possible values are: hd, network and/or cdrom" unless default_boot_order.include?(b)
+              raise "invalid boot order, possible values are any combination of: #{valid_boot_media.join(', ')}" unless valid_boot_media.include?(b)
             end
           end
         end
