@@ -6,6 +6,10 @@ Shindo.tests('Fog::Compute[:libvirt] | network model', ['libvirt']) do
   tests('The network model should') do
     tests('have the action') do
       test('reload') { network.respond_to? 'reload' }
+      test('dhcp_leases') { network.respond_to? 'dhcp_leases' }
+    end
+    tests('have a dhcp_leases action that') do
+      test('returns an array') { network.dhcp_leases('99:88:77:66:55:44', 0).kind_of? Array }
     end
     tests('have attributes') do
       model_attribute_hash = network.attributes
